package hello.jsp;

import java.io.*;
import junit.framework.*;

/** 
 * Tests binding of command names to objects.
 * $Revision: 1.2 $ $Date: 2002/09/28 20:27:30 $ (helder@acm.org).
 */
public class CommandFactoryTest extends TestCase {
    
    public CommandFactoryTest(String name) {
        super(name);
    }
    public static Test suite() {
        return new TestSuite(CommandFactoryTest.class);
    }
    
    /////////////// Fixture ///////////////////
    CommandFactory factory;
    
    public void setUp() throws IOException {
        // We know this file exists - may fail if file changes place
        factory = CommandFactory.getInstance("webinf/mapping.xml");
    }

    /**
     * Asserts that the correct command (with the correct class and parameters) was
     * retrieved from the command factory.
     */
    public void testGetCommand() throws CommandNotFoundException {
        String commandName = "newMessage";
        Command expectedCommand = new hello.jsp.NewMessageCommand("/lastMessage.jsp", "/index.html");
        Command result = factory.getCommand(commandName);
        assertEquals(expectedCommand, result);
    }
    
    public void testGetCommandFailure() {
        String commandName = "bogus";
        try {
            Command result = factory.getCommand(commandName);
            fail("Command bogus does not exist - exception should have been thrown!");
        } catch (CommandNotFoundException e) {
            // OK
        }
    }
}
