package hello.jsp; 

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.File;

/**
 * This is the front controller of the application.
 * $Revision: 1.3 $ $Date: 2002/10/06 14:24:58 $ (helder@acm.org).
 */
public class ControlServlet extends HttpServlet {
    
    /**
     * The data access object which provedes the persistence mechanism for this application.
     */
    private MessageBeanDAO dao;
    
    /**
     * This is a command-mapping utility.
     */
    private CommandFactory commands;
    
    /**
     * Servlet initialization.
     */
    public void init(ServletConfig config) throws UnavailableException {
        String mappingsFile = config.getInitParameter("mappings-file");
        if (mappingsFile == null) {
            throw new UnavailableException("Required parameter mappings-file not found in deployment descriptor");
        }
        
        // Persistence mechanism and location
        String messageDir = config.getInitParameter("message-dir");
        String dsn = config.getInitParameter("data-source-name");
        if (dsn == null && messageDir != null) { // using XML persistence
            dao = new XMLMessageBeanDAO(messageDir);
        } else if (messageDir == null && dsn != null) { // using datasource persistence
            //dao = new JDOMessageBeanDAO(dsn);
            throw new UnavailableException("JDO persistence not yet implemented! Use XML binding!");
        } else {
            throw new UnavailableException("Either message-dir or data-source-name must be present in deployment descriptor");
        }
        
        // This class receives the name of an XML file which contains command-action object mappings
        // and returns an object that can return action objects by name.
        try {
            String filePath = config.getServletContext().getRealPath(mappingsFile);
            commands = CommandFactory.getInstance(filePath);
        } catch (Exception e) {
            throw new UnavailableException("" + e);
        }
    }
    
    /**
     * Servlet execution. Gets command object from command name and executes it. Forwards
     * to the page returned by the command execution.
     */
    public void service(HttpServletRequest request,
                        HttpServletResponse response) throws ServletException, java.io.IOException {

        Command command = null;
        String commandName = request.getParameter("cmd");
        if (commandName == null) {
            command = commands.getCommand("default");
        } else {
            try {
                command = commands.getCommand(commandName);
            } catch (CommandNotFoundException e) {
                command = commands.getCommand("default");
            }
        }

        Object result = command.execute(request, response, dao);
        if (result instanceof String) {
            RequestDispatcher dispatcher = request.getRequestDispatcher((String)result);
            dispatcher.forward(request, response);
        } else {
            throw new ServletException("Command returned an invalid response: " + result);
        }
    }
}
