package hello.jsp;

import javax.servlet.*;
import javax.servlet.http.*; 

import org.apache.cactus.*;
import junit.framework.*;

import org.xml.sax.SAXException;
import java.io.IOException;

/**
 * Cactus test for the front controller.
 * $Revision: 1.3 $ $Date: 2002/10/06 14:24:59 $ (helder@acm.org).
 */
public class ControlServletTest extends ServletTestCase {
    
    public ControlServletTest(String name) {
        super(name);
    }
    public static Test suite() {
        return new TestSuite(ControlServletTest.class);
    }

    private String testMessage = "This is a Web Message.";
    
    ///////////// Client Set Up //////////////////////////////////////////
    
    public void beginServiceNewMessage(WebRequest clientRequest) {
        clientRequest.addParameter("cmd", "newMessage");
        clientRequest.addParameter("message", testMessage);
    }
    
    public void beginServiceShowLastMessage(WebRequest clientRequest) {
        clientRequest.addParameter("cmd", "showLastMessage");
    }
    
    public void beginServiceShowMessages(WebRequest clientRequest) {
        clientRequest.addParameter("cmd", "showAllMessages");
    }
    
    public void beginServiceDefaultCommand(WebRequest clientRequest) {
        // nothing or unknown command
    }
    
    /////////////// Server set up and fixture /////////////////////////////
    
    private HttpServlet servlet;
    private String messageDir = "/tmp/test";
    
    public void setUp() throws ServletException {
        config.setInitParameter("mappings-file", "/WEB-INF/mapping.xml");
        config.setInitParameter("message-dir", messageDir);
        servlet = new ControlServlet();
        servlet.init(this.config);
    }
    
    /////////////// Server-side tests /////////////////////////////////////
    /**
     * Not much to do since most of the testing occurs in action objects.
     */
    public void _testService() throws ServletException, IOException {
        System.out.print("Starting servlet...");
        servlet.service(this.request, this.response);
        // Tested commands should have been executed and tested results obtained (no testing needed here)
        // forwarding is tested in endXXX()
        System.out.println("Server side testing is done.");
    }
    public void testServiceNewMessage() throws ServletException, IOException { 
        assertEquals("newMessage", request.getParameter("cmd"));
        assertEquals(testMessage, request.getParameter("message"));
        _testService(); 
    }
    public void testServiceShowLastMessage() throws ServletException, IOException  { 
        assertEquals("showLastMessage", request.getParameter("cmd")); 
        _testService(); 
    }
    public void testServiceShowMessages() throws ServletException, IOException  { 
        assertEquals("showAllMessages", request.getParameter("cmd")); 
        _testService(); 
    }
    public void testServiceDefaultCommand() throws ServletException, IOException  { 
        _testService();
    }
    
    /////////////////// Interface tests ///////////////////////////////////
    public void endServiceNewMessage(com.meterware.httpunit.WebResponse clientResponse) throws SAXException, IOException {
        // Must contain page with message sent
        // Check if this is the right page
        String pageTitle = clientResponse.getTitle();
        assertTrue("Wrong page: " + pageTitle, pageTitle.indexOf("Last Message") >= 0);
        // Check if page contains message
        String responseString = clientResponse.getText();
        assertTrue("Test Message is not in result page!", responseString.indexOf(testMessage) >= 0);
    }
    
    /**
     * Checking only if the page is the correct one!.
     */
    public void endServiceShowLastMessage(com.meterware.httpunit.WebResponse clientResponse) throws SAXException, IOException {
        // Must contain page with last message sent
        // Check if this is the right page
        String pageTitle = clientResponse.getTitle();
        assertTrue("Wrong page: " + pageTitle, pageTitle.indexOf("Last Message") >= 0);
    }
    
    /**
     * Checking only if the page is the correct one!.
     */
    public void endServiceShowMessages(com.meterware.httpunit.WebResponse clientResponse) throws SAXException, IOException {
        // Must contain page with list of messages. The number of messages must be equivalent
        // to the number of files available.
        // Check if this is the right page
        String pageTitle = clientResponse.getTitle();
        assertTrue("Wrong page: " + pageTitle, pageTitle.indexOf("All Messages") >= 0);
    }
    
    /**
     * Checking only if the page is the correct one!.
     */
    public void endServiceDefaultCommand(com.meterware.httpunit.WebResponse clientResponse) throws SAXException, IOException {
        // Must contain page with last message sent
        // Check if this is the right page
        String pageTitle = clientResponse.getTitle();
        assertTrue("Wrong page: " + pageTitle, pageTitle.indexOf("New Message") >= 0);
    }
}
