package hello.jsp;

import javax.servlet.*; 
import javax.servlet.http.*;
import java.io.*;

/**
 * Creates a new message file and increments the message file counter.
 * $Revision: 1.3 $ $Date: 2002/10/06 14:24:59 $ (helder@acm.org).
 */
public class NewMessageCommand implements Command {
    
    private String successUrl;
    private String failureUrl;
    private String persistenceLocation;
    
    public NewMessageCommand(String successUrl, String failureUrl) {
        this.successUrl = successUrl;
        this.failureUrl = failureUrl;
    }
    
    /**
     * Creates a new MessageBean. Sets a request
     * attribute which contains the message that was created.
     */
    public Object execute(HttpServletRequest request, HttpServletResponse response, MessageBeanDAO dao) throws CommandException {

        String message = request.getParameter("message");
        String time = java.text.DateFormat.getDateTimeInstance(java.text.DateFormat.MEDIUM, java.text.DateFormat.SHORT).format(new java.util.Date());
        String host = request.getRemoteHost();
        
        MessageBean bean = new MessageBean();
        
        bean.setMessage(message);
        bean.setTime(time);
        bean.setHost(host);
        
        try {
            // Data tier independent persistent mechanism. Althoug bean has built in XML binding
            // capabilities, we may wish, in the future, to save the data, for example, in a database
            dao.persist(bean);
            
            request.setAttribute("messageBean", bean);
            return successUrl;
        } catch (PersistenceException e) {
            throw new CommandException(e);   
        }
    }
    
    /**
     * Object.toString() implementation.
     */
    public String toString() {
        return this.getClass().getName() + "(\"" + successUrl + "\", \"" + failureUrl + "\")";
    }
    
    /**
     * Object.equals() implementation.
     */
    public boolean equals(Object obj) {
        if ( !(obj instanceof NewMessageCommand) ) return false;
        NewMessageCommand cmd = (NewMessageCommand) obj;
        return successUrl.equals(cmd.successUrl) && failureUrl.equals(cmd.failureUrl);
    }
    
    /**
     * Object.hashCode() implementation.
     */
    public int hashCode() {
        return 37 * successUrl.hashCode() * failureUrl.hashCode();
    }
}
