package hello.jsp;

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.*;
 
/**
 * Opens the message XML file that has the highest index number and unmarshals it from
 * XML back to JavaBean.
 * $Revision: 1.3 $ $Date: 2002/10/06 14:24:59 $ (helder@acm.org).
 */
public class ShowLastMessageCommand implements Command {
    
    private String successUrl;
    private String failureUrl;
    
    public ShowLastMessageCommand(String successUrl, String failureUrl) {
        this.successUrl = successUrl;
        this.failureUrl = failureUrl;
    }
    
    /**
     * Unmarshals message files.
     */
    public Object execute(HttpServletRequest request, HttpServletResponse response, MessageBeanDAO dao) throws CommandException {
        try {
            MessageBean bean = dao.retrieveLast(); 
            request.setAttribute("messageBean", bean);
            return successUrl;
        } catch (PersistenceException e) {
            throw new CommandException("Unable to read last message: " + e, e);
        } 
    }
    
    /**
     * Object.toString() implementation.
     */
    public String toString() {
        return this.getClass().getName() + "(\"" + successUrl + "\", \"" + failureUrl + "\")";
    }
    
    /**
     * Object.equals() implementation.
     */
    public boolean equals(Object obj) {
        if ( !(obj instanceof ShowLastMessageCommand) ) return false;
        ShowLastMessageCommand cmd = (ShowLastMessageCommand) obj;
        return successUrl.equals(cmd.successUrl) && failureUrl.equals(cmd.failureUrl);
    }
    
    /**
     * Object.hashCode() implementation.
     */
    public int hashCode() {
        return 37 * successUrl.hashCode() * failureUrl.hashCode();
    }
}
