package hello.jsp; 

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.*;

import org.apache.cactus.*;
import junit.framework.*;

/** 
 * Testing for JAXB implementation of DAO (refactor so tests can apply to any version).
 * $Revision: 1.3 $ $Date: 2002/10/06 14:25:00 $ (helder@acm.org).
 */
public class ShowLastMessageCommandTest extends ServletTestCase {
    
    public ShowLastMessageCommandTest(String name) {
        super(name);
    }
    public static Test suite() {
        return new TestSuite(ShowLastMessageCommandTest.class);
    }

    private ShowLastMessageCommand command;
    private MessageBeanDAO dao;
    private String testMessage = "This is a test message"; // this is the text for all messages
    
    public void beginExecute(WebRequest clientRequest) {
        // no parameters to set
    }
    
    public void setUp() throws IOException {
        File testDir = new File("/tmp/test");
        testDir.mkdir();
        dao = new XMLMessageBeanDAO("/tmp/test");
        command = new ShowLastMessageCommand("/lastMessage.jsp", "/index.html");
    }
    
    /**
     * This test is practically the same as the test for NewMessageCommand. The difference is
     * that the message received was unmarshaled from the XML file. Additionally, this test
     * will only run if the files exist (ex: the other test must run before this one.)
     * We do not test to see the contents of this message since this test has no control over that.
     */
    public void testExecute() throws CommandException {
        Object obj = command.execute(request, response, dao); // if return type is not String, exception will occur
        
        // message.count should exist
        File countFile = new File("/tmp/test/message.count");
        assertTrue("Count file does not exist!", countFile.exists());
        
        // lastMessage attribute in request should exist with messageBean
        // This is an unmarshaled version
        Object attribute = request.getAttribute("messageBean");
        assertNotNull("No attribute messageBean exists in Session.", attribute);
        MessageBean bean = (MessageBean)attribute;
        String result = bean.getMessage();
        assertNotNull("Message is null.", result); // we just check that there is a message
        System.out.println("Last message found: " + result);
        
        // returned object should contain success argument
        String returned = (String) obj;
        assertEquals("Value returned is incorrect.", "/lastMessage.jsp", returned);
    }
    
}
