package hello.jsp; 

import javax.servlet.*;
import javax.servlet.http.*;
import java.io.*;
import java.util.ArrayList;

/**
 * Reads all files in messages directory and unmarshals them from XML to JavaBean.
 * $Revision: 1.3 $ $Date: 2002/10/06 14:25:00 $ (helder@acm.org).
 */
public class ShowMessagesCommand implements Command {
    
    private String successUrl;
    private String failureUrl;
    
    public ShowMessagesCommand(String successUrl, String failureUrl) {
        this.successUrl = successUrl;
        this.failureUrl = failureUrl;
    }
    
    /**
     * Reads all messages from XML files.
     */
    public Object execute(HttpServletRequest request, HttpServletResponse response, MessageBeanDAO dao) throws CommandException {
        try {
            MessageBean[] beanArray = dao.retrieveAll();
            request.setAttribute("messages", beanArray);
            return successUrl;
        } catch (PersistenceException e) {
            throw new CommandException(e);   
        } 
    }

    /**
     * Object.toString() implementation.
     */
    public String toString() {
        return this.getClass().getName() + "(\"" + successUrl + "\", \"" + failureUrl + "\")";
    }
    
    /**
     * Object.equals() implementation.
     */
    public boolean equals(Object obj) {
        if ( !(obj instanceof ShowMessagesCommand) ) return false;
        ShowMessagesCommand cmd = (ShowMessagesCommand) obj;
        return successUrl.equals(cmd.successUrl) && failureUrl.equals(cmd.failureUrl);
    }
    
    /**
     * Object.hashCode() implementation.
     */
    public int hashCode() {
        return 37 * successUrl.hashCode() * failureUrl.hashCode();
    }
}
