package hello.jsp;

import javax.servlet.*;
import javax.servlet.http.*; 
import java.io.*;

import org.apache.cactus.*;
import junit.framework.*;

/**
 * Testing for JAXB implementation of DAO (refactor so tests can apply to any version).
 * $Revision: 1.3 $ $Date: 2002/10/06 14:25:00 $ (helder@acm.org).
 */
public class ShowMessagesCommandTest extends ServletTestCase {
    
    public ShowMessagesCommandTest(String name) {
        super(name);
    }
    public static Test suite() {
        return new TestSuite(ShowMessagesCommandTest.class);
    }

    private ShowMessagesCommand command;
    private MessageBeanDAO dao;
    private String testMessage = "This is a test message"; // this is the text for all messages
    
    public void beginExecute(WebRequest clientRequest) {
        // no parameters to set
    }
    
    public void setUp() throws IOException {
        File testDir = new File("/tmp/test");
        testDir.mkdir();
        dao = new XMLMessageBeanDAO("/tmp/test");
        command = new ShowMessagesCommand("/messages.jsp", "/index.html");
    }
    
    /**
     * This test is practically the same as the test for NewMessageCommand. The difference is
     * that the message received was unmarshaled from the XML file. Additionally, this test
     * will only run if the files exist (ex: the other test must run before this one.)
     */
    public void testExecute() throws CommandException {
        Object obj = command.execute(request, response, dao); // if return type is not String, exception will occur
        
        // message.count should exist
        File countFile = new File("/tmp/test/message.count");
        assertTrue("Count file does not exist!", countFile.exists());
        
        // lastMessage attribute in request should exist with array of messageBean
        Object attribute = request.getAttribute("messages");
        assertNotNull("No attribute messages exists in Request.", attribute);
        MessageBean[] beans = (MessageBean[])attribute;
        
        // beans.length should be equivalent to the number of message_?.xml files in messageDir
        int files = this.getTotalFiles();
        assertEquals("Array lengths don't match", files, beans.length);
        
        // Open each bean and assert that each message is not null
        for (int i = 0; i < beans.length; i++) {
            String result = beans[i].getMessage();
            assertNotNull("Message is null.", result);
            System.out.println("Message found: " + result);
        }
        
        // returned object should contain success argument
        String returned = (String) obj;
        assertEquals("Value returned is incorrect.", "/messages.jsp", returned);
    }
    
    /**
     * Length of files in test directory
     */
    private int getTotalFiles() {
        String messageDir = "/tmp/test";
        File dir = new File(messageDir);
        File[] files = dir.listFiles(new FilenameFilter() {
            public boolean accept(File dir, String fileName) {
                return (new File(dir, fileName)).isFile() 
                       && fileName.endsWith(".xml")     
                       && fileName.startsWith("message_");
            }
        });
        return files.length;
    }
    
}
