package hello.taglib;
 
import javax.servlet.*;
import javax.servlet.jsp.*; // JspWriter, JspException, JspTagException
import javax.servlet.jsp.tagext.*; // TagSupport, Tag

import hello.jsp.MessageBean;

/**
 * Example of a simple empty content tag. It may be used inside a PrintMessages tag, for
 * iterative repetition, or standalone. Whe used standalone, the beanName attribute is
 * required. It is optional otherwise. The only attribute always required is the property
 * attribute.
 * $Revision: 1.2 $ $Date: 2002/09/28 20:27:28 $ (helder@acm.org).
 */
public class PrintFieldTag extends TagSupport {
    
    private String  prefix = "", // default suffix
                    suffix = "", // default prefix
                    property, 
                    beanName;
    
    /**
     * Setter for the name attribute.
     */
    public void setName(String beanName) {
        this.beanName = beanName;
    }
    
    /**
     * Setter for the property attribute.
     */
    public void setProperty(String property) {
        this.property = property;
    }
    
    /**
     * Setter for the suffix attribute.
     */
    public void setSuffix(String suffix) {
        this.suffix = suffix;
    }
    
    /**
     * Setter for the prefix attribute.
     */
    public void setPrefix(String prefix) {
        this.prefix = prefix;
    }
    
    /**
     * Processed before the contents of the tag. This tag can be used with or without a
     * <printMessages> parent. If it is used without one, it will require a beanName
     * attribute matching an available bean in request scope. Otherwise, it will look
     * for an ancestor of PrintMessagesTag class and extract its current message.
     */
    public int doStartTag() throws JspException {
        // Gets reference to this page's out scripting variable
        JspWriter out = pageContext.getOut();
        try {
            // get bean from request (available when used without parent)
            MessageBean bean = null;
            if (beanName != null) {
                bean = (MessageBean)pageContext.getRequest().getAttribute(beanName);
            }
            if (bean == null) { // either beanName is null or beanName does not correspond to request attribute
                // get bean name from page context inside <printMessages> tag
                PrintMessagesTag parent = (PrintMessagesTag)
                    TagSupport.findAncestorWithClass(this, PrintMessagesTag.class);
                if (parent == null) {
                    throw new JspException("Required <printMessages> parent when name attribute is omitted.");
                }
                // Get message from current iteration
                bean = parent.getCurrentMessage();
                // if it is still null, then throw an exception
                if (bean == null) {
                    throw new JspException("MessageBean is not defined in tag context for JSP page.");
                }
            }
            // TagUtils is a local utility class
            String field = TagUtils.getPropertyValue(bean, property);
            if (field == null) {
                throw new JspException(property + " is not defined in MessageBean.");
            }
            out.println(prefix + field + suffix);
        } catch (java.io.IOException e) {
            throw new JspTagException("PrintFieldTag - " + e);
        }
        return Tag.SKIP_BODY;
    }
    
    /**
     * Our class does not need to implement this method.
     */
    public int doEndTag() {
        //System.out.println("doEndTag called in PrintField!");
        return Tag.EVAL_PAGE;
    }
    
    /**
     * Cleanup.
     */
    public void release() {
        super.release();
        prefix = null;
        suffix = null;
        property = null;
        beanName = null;
    }
    
}
