package hello.taglib;
 
import javax.servlet.*;
import javax.servlet.jsp.*; // JspWriter, JspException, JspTagException
import javax.servlet.jsp.tagext.*; // TagSupport, Tag

import hello.jsp.MessageBean;

import org.apache.cactus.*;
import junit.framework.*;

/**
 * $Revision: 1.2 $ $Date: 2002/09/28 20:27:27 $ (helder@acm.org).
 */
public class PrintMessagesTagTest extends JspTestCase {
    
    public PrintMessagesTagTest(String name) {
        super(name);
    }
    public static Test suite() {
        return new TestSuite(PrintMessagesTagTest.class);
    }
    
    private PrintMessagesTag tag;
    private MessageBean[] testBeans;
    private BodyContent bodyContent;
    
    /**
     * Tag initialization.
     */
    public void setUp() throws JspException {
        // Create array of three messages
        testBeans = new MessageBean[3];
        for (int i = 0; i < testBeans.length; i++) {
            testBeans[i] = new MessageBean();
            testBeans[i].setMessage("This is Cactus Test Message number " + (i+1));
            testBeans[i].setTime("12/12/2002 13:45");
            testBeans[i].setHost("somehost");
        }
        request.setAttribute("beans", testBeans);
        
        tag = new PrintMessagesTag();
        
        // This is necessary to pass the testcase's pageContext to the tag
        tag.setPageContext(this.pageContext);
        
        // expected values
        tag.setArray("beans");
        tag.doInitBody();
        // doStartTag would enter here, but we are testing it!
    }
    
    /** 
     * Asserts that body content is processed.
     */
    public void testDoStartTag() throws JspException {
        assertEquals("Start tag not processing body!", BodyTag.EVAL_BODY_BUFFERED, tag.doStartTag());
    }
    
    /**
     * Tests the contents of the tag.
     */
    public void testDoAfterBody() throws JspException, java.io.IOException {
        // Must call doStartTag()
        tag.doStartTag();
        // Set tag with bodyContent object reference
        bodyContent = pageContext.pushBody();
        tag.setBodyContent(bodyContent);
        // start loop
        int count = 0;
        do { // first time is in doStartTag()
            // Set a message in bodyContent
            bodyContent.print("<test>"+testBeans[count].getMessage()+"</test>");
            // clearBody() resets body so this should contain only current iteration
            assertEquals("Unexpected contents.", 
                        "<test>This is Cactus Test Message number " + (count + 1) + "</test>",
                        tag.getBodyContent().getString());
            count++;
        } while (tag.doAfterBody() == tag.EVAL_BODY_BUFFERED);
        pageContext.popBody();
        
        //based on setUp we expect 3 repetitions
        assertEquals(3, count);
        // There should be nothing in the bodyContent after clearBody()
        assertEquals("Body Content not empty!", "", tag.getBodyContent().getString().trim());
    }
    
    /**
     * Tests generated string.
     */
    public void endDoAfterBody(WebResponse response) {
        String resultString = "";
        for (int i = 0; i < 3; i++) {
            resultString += "<test>This is Cactus Test Message number " + (i + 1) + "</test>";
        }
        assertEquals(resultString, response.getText());
    }
}
