package hello.taglib;

import javax.servlet.*;
import javax.servlet.jsp.*; // JspWriter, JspException, JspTagException
import java.lang.reflect.*; // Method
import java.beans.*; // BeanInfo, Introspector, PropertyDescriptor 

import hello.jsp.MessageBean;

/**
 * Utility methods for custom tags.
 * $Revision: 1.2 $ $Date: 2002/09/28 20:27:27 $ (helder@acm.org).
 */
public class TagUtils {
    
    /**
     * Utility method that extracts the desired property from the
     * bean and returns its String value.
     */
    public static String getPropertyValue(MessageBean bean, String property) throws JspTagException {
        try {
            // Get bean's class
            Class beanClass = bean.getClass();
            // Get bean info (necessary to discover methods associated with properties
            BeanInfo beanInfo = Introspector.getBeanInfo(beanClass); 
            // Property descriptors
            PropertyDescriptor[] descriptors = beanInfo.getPropertyDescriptors(); 
            // Find method
            Method getter = null;
            for (int i = 0; i < descriptors.length; i++) { 
                if (descriptors[i].getName().equals(property)) {
                    getter = descriptors[i].getReadMethod();
                    break;
                }
            }
            if (getter == null) {
                throw new IntrospectionException("No property matching " + property + " was found.");
            }
            // invokes method: invoke(beanInstance, methodParameters[])
            String result = (String) getter.invoke(bean, null);
            return result;
        } catch (Exception e) {
            if (e instanceof IntrospectionException) throw new JspTagException("TagUtils.getPropertyValue() - " + e);
            if (e instanceof RuntimeException) throw (RuntimeException) e;
            throw new JspTagException("TagUtils.getPropertyValue() - " + e);
        }
    }
    
}
